@@ -8,7 +8,7 @@ from __future__ import absolute_import, unicode_literals
 import json
 from datetime import date, datetime, timedelta
 
-from unittest2 import skipIf
+from unittest import skipIf
 
 from django.test import TestCase
 
@@ -21,28 +21,29 @@ from drf_haystack.serializers import HaystackSerializer, HaystackFacetSerializer
 from drf_haystack.filters import (
     HaystackAutocompleteFilter, HaystackBoostFilter,
     HaystackFacetFilter, HaystackFilter,
-    HaystackGEOSpatialFilter, HaystackHighlightFilter
+    HaystackGEOSpatialFilter, HaystackHighlightFilter,
+    HaystackOrderingFilter
 )
 from drf_haystack.mixins import FacetMixin
 
-from . import geospatial_support
-from .mixins import WarningTestCaseMixin
+from . import geospatial_support, elasticsearch_version
 from .constants import MOCKLOCATION_DATA_SET_SIZE, MOCKPERSON_DATA_SET_SIZE
-from .mockapp.models import MockLocation, MockPerson
-from .mockapp.search_indexes import MockLocationIndex, MockPersonIndex
+from .mixins import WarningTestCaseMixin
+from .mockapp.models import MockAllField, MockLocation, MockPerson
+from .mockapp.search_indexes import MockAllFieldIndex, MockLocationIndex, MockPersonIndex
 
 factory = APIRequestFactory()
 
 
 class HaystackFilterTestCase(TestCase):
 
-    fixtures = ["mockperson"]
+    fixtures = ["mockperson", "mockallfield"]
 
     def setUp(self):
+        MockAllFieldIndex().reindex()
         MockPersonIndex().reindex()
 
         class Serializer1(HaystackSerializer):
-
             class Meta:
                 index_classes = [MockPersonIndex]
                 fields = ["text", "firstname", "lastname",
@@ -53,7 +54,6 @@ class HaystackFilterTestCase(TestCase):
                 }
 
         class Serializer2(HaystackSerializer):
-
             class Meta:
                 index_classes = [MockLocationIndex]
                 exclude = ["lastname"]
@@ -62,6 +62,11 @@ class HaystackFilterTestCase(TestCase):
             # This is not allowed. Must implement a `Meta` class.
             pass
 
+        class Serializer5(HaystackSerializer):
+            class Meta:
+                index_classes = [MockAllFieldIndex]
+                fields = ["integerfield"]
+
         class ViewSet1(HaystackViewSet):
             index_models = [MockPerson]
             serializer_class = Serializer1
@@ -73,9 +78,13 @@ class HaystackFilterTestCase(TestCase):
         class ViewSet3(ViewSet1):
             serializer_class = Serializer4
 
+        class ViewSet4(HaystackViewSet):
+            serializer_class = Serializer5
+
         self.view1 = ViewSet1
         self.view2 = ViewSet2
         self.view3 = ViewSet3
+        self.view4 = ViewSet4
 
     def tearDown(self):
         MockPersonIndex().clear()
@@ -194,6 +203,16 @@ class HaystackFilterTestCase(TestCase):
         response = self.view1.as_view(actions={"get": "list"})(request)
         self.assertEqual(len(response.data), MockPerson.objects.filter(birthdate__lt=date(1980, 1, 1)).count())
 
+    def test_filter_in_integerfield(self):
+        request = factory.get(path="/", data={"integerfield__in": "48,57"}, content_type="application/json")
+        response = self.view4.as_view(actions={"get": "list"})(request)
+        self.assertEqual(len(response.data), MockAllField.objects.filter(integerfield__in=[48, 57]).count())
+
+    def test_filter_range_integerfield(self):
+        request = factory.get(path="/", data={"integerfield__range": "300,500"}, content_type="application/json")
+        response = self.view4.as_view(actions={"get": "list"})(request)
+        self.assertEqual(len(response.data), MockAllField.objects.filter(integerfield__range=[300, 500]).count())
+
 
 class HaystackAutocompleteFilterTestCase(TestCase):
 
@@ -317,6 +336,7 @@ class HaystackHighlightFilterTestCase(TestCase):
     def tearDown(self):
         MockPersonIndex().clear()
 
+    @skipIf(not elasticsearch_version < (2, ), "Highlighting is not yet supported for the Elasticsearch2 backend")
     def test_filter_highlighter_filter(self):
         request = factory.get(path="/", data={"firstname": "jeremy"}, content_type="application/json")
         response = self.view.as_view(actions={"get": "list"})(request)
@@ -490,3 +510,85 @@ class HaystackFacetFilterTestCase(WarningTestCaseMixin, TestCase):
     def test_filter_facet_warn_on_inproperly_formatted_token(self):
         request = factory.get("/", data={"firstname": "token"}, content_type="application/json")
         self.assertWarning(UserWarning, self.view2.as_view(actions={"get": "facets"}), request)
+
+
+class OrderedHaystackViewSetTestCase(TestCase):
+
+    fixtures = ["mockallfield"]
+
+    def setUp(self):
+        MockAllFieldIndex().reindex()
+
+        class Serializer(HaystackSerializer):
+            class Meta:
+                fields = ("charfield", "integerfield", "floatfield",
+                          "decimalfield", "boolfield")
+                index_classes = [MockAllFieldIndex]
+
+        class ViewSet1(HaystackViewSet):
+            index_models = [MockAllField]
+            serializer_class = Serializer
+            filter_backends = (HaystackOrderingFilter,)
+            ordering_fields = "__all__"
+            ordering = ("integerfield",)
+
+        class ViewSet2(HaystackViewSet):
+            index_models = [MockAllField]
+            serializer_class = Serializer
+            filter_backends = (HaystackOrderingFilter,)
+            ordering_fields = "__all__"
+            ordering = ("-integerfield",)
+
+        self.view1 = ViewSet1
+        self.view2 = ViewSet2
+
+    def tearDown(self):
+        MockAllFieldIndex().clear()
+
+    def test_viewset_default_ordering(self):
+        request = factory.get(path="/", content_type="application/json")
+        response = self.view1.as_view(actions={"get": "list"})(request)
+
+        response.render()
+        content = json.loads(response.content.decode())
+
+        self.assertEqual(
+            [result["integerfield"] for result in content],
+            list(MockAllField.objects.values_list("integerfield", flat=True).order_by("integerfield"))
+        )
+
+    def test_viewset_default_reverse_ordering(self):
+        request = factory.get(path="/", content_type="application/json")
+        response = self.view2.as_view(actions={"get": "list"})(request)
+
+        response.render()
+        content = json.loads(response.content.decode())
+
+        self.assertEqual(
+            [result["integerfield"] for result in content],
+            list(MockAllField.objects.values_list("integerfield", flat=True).order_by("-integerfield"))
+        )
+
+    def test_viewset_order_by_single_query_param(self):
+        request = factory.get(path="/", data={"ordering": "integerfield"}, content_type="application/json")
+        response = self.view1.as_view(actions={"get": "list"})(request)
+
+        response.render()
+        content = json.loads(response.content.decode())
+
+        self.assertEqual(
+            [result["integerfield"] for result in content],
+            list(MockAllField.objects.values_list("integerfield", flat=True).order_by("integerfield"))
+        )
+
+    def test_viewset_order_by_multiple_query_params(self):
+        request = factory.get(path="/", data={"ordering": "integerfield,boolfield"}, content_type="application/json")
+        response = self.view1.as_view(actions={"get": "list"})(request)
+
+        response.render()
+        content = json.loads(response.content.decode())
+
+        self.assertEqual(
+            [result["integerfield"] for result in content],
+            list(MockAllField.objects.values_list("integerfield", flat=True).order_by("integerfield", "boolfield"))
+        )
