@@ -106,16 +106,16 @@ class HaystackSerializerTestCase(WarningTestCaseMixin, TestCase):
         class Serializer1(HaystackSerializer):
 
             integer_field = serializers.IntegerField()
-            city = serializers.CharField()
+            city = serializers.SerializerMethodField()
 
             class Meta:
                 index_classes = [MockPersonIndex]
                 fields = ["text", "firstname", "lastname", "autocomplete"]
 
-            def get_integer_field(self, obj):
+            def get_integer_field(self, instance):
                 return 1
 
-            def get_city(self, obj):
+            def get_city(self, instance):
                 return "Declared overriding field"
 
         class Serializer2(HaystackSerializer):
@@ -204,6 +204,12 @@ class HaystackSerializerTestCase(WarningTestCaseMixin, TestCase):
         self.assertTrue(dog.data["has_rabies"])
         self.assertFalse(iguana.data["has_rabies"])
 
+    def test_serializer_declared_field_overrides(self):
+        obj = SearchQuerySet().filter(lastname="Foreman")[0]
+        serializer = self.serializer1(instance=obj)
+
+        self.assertEqual(serializer.data['city'], "Declared overriding field")
+
 
 class HaystackSerializerAllFieldsTestCase(TestCase):
 
@@ -256,17 +262,17 @@ class HaystackSerializerMultipleIndexTestCase(WarningTestCaseMixin, TestCase):
             """
             Multiple index serializer with declared fields
             """
-            _MockPersonIndex__hair_color = serializers.CharField()
-            extra = serializers.IntegerField()
+            _MockPersonIndex__hair_color = serializers.SerializerMethodField()
+            extra = serializers.SerializerMethodField()
 
             class Meta:
                 index_classes = [MockPersonIndex, MockPetIndex]
                 exclude = ["firstname"]
 
-            def get__MockPersonIndex__hair_color(self):
+            def get__MockPersonIndex__hair_color(self, instance):
                 return "black"
 
-            def get_extra(self):
+            def get_extra(self, instance):
                 return 1
 
         class Serializer3(HaystackSerializer):
